# TCD pipeline tool

CLI tool for convert TCD pipelines to ArgoWrokflows manifests.

---

## Build

Build instruction can be found at [BUILD.md](BUILD.md)

---

## Release

Release instruction and history can be found at [RELEASE.md](RELEASE.md)

---

## Install

```sh
pip install tcd-pipeline
```

---

## Usage

Running from installed

```sh
tcd-pipeline --help
```

Running with python module

```sh
python -m tcd_pipeline
```
